@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 from balladeer.drama import Drama
 from balladeer.speech import Article
@@ -7,16 +7,25 @@ from balladeer.speech import Name
 from balladeer.speech import Phrase
 from balladeer.speech import Pronoun
 from balladeer.speech import Verb
+from balladeer.story import Story
 from balladeer.types import Grouping
 from balladeer.types import Named
 from balladeer.types import World
 
 from turberfield.catchphrase.parser import CommandParser
+
 from turberfield.catchphrase.presenter import Presenter
+
+from turberfield.catchphrase.render import Action
+from turberfield.catchphrase.render import Parameter
 from turberfield.catchphrase.render import Renderer
 from turberfield.catchphrase.render import Settings
 
 from turberfield.dialogue.model import SceneScript
 from turberfield.dialogue.model import Model
+
 from turberfield.dialogue.types import DataObject
+from turberfield.dialogue.types import EnumFactory
 from turberfield.dialogue.types import Stateful
+
+from turberfield.utils.assembly import Assembly
